/**
 * Class for performing test on magic squares
 */
public class MagicSquareTest {

    public static final int dimension = 5; // dimension    
    public static int iters = 100000;  // iterations to perform
    public static int iprint = 5;  

    private MagicSquare square;
    private int d;
    private double[][] matrix;
    
    
    /** Creates new MagicSquareTest instance by given MagicSquare instance
     * @param square MagicSquare instance
     */
    public MagicSquareTest(MagicSquare square) {
        this.square = square;
        d = square.getDimension();
    }
    
    public void perform() {
        double[][] m1 = new double[d][d];
        double[][] m2 = new double[d][d];
        double[][] m3 = new double[d][d];
        double[][] buf = null;

        double sum = d*(d*d + 1)/2;
        
        // normalization
        for (int i = 0; i < d; i++) {
            for (int j = 0; j < d; j++) {
                m1[i][j] = m2[i][j] = square.getSquareAsArray()[i][j] / sum;
            }
        }
        
        for (int iter = 0; iter < iters; iter++) {
            for (int i = 0; i < d; i++) {
                for (int j = 0; j < d; j++) {
                    double value = 0;
                    for (int k = 0; k < d; k++) {
                         value += m1[k][j] * m2[i][k];
                    }
                    m3[i][j] = value;
                }
            }
            buf = m2; m2 = m3; m3 = buf;
        }
        
        matrix = m2;
    }
    
    public void printMatrix() {
        if (matrix == null) return;
        for (int i = 0; i < d; i++) {
            for (int j = 0; j < d; j++) {
                System.out.print(matrix[i][j] + " ");
            }
            System.out.println();
        }
    }
        
    /**
    * @param args the command line arguments
    */
/*
    public static void main (String args[]) {
        
        for (int i = 0; i < iprint; i++) {
        
            long startTime = System.currentTimeMillis();
            
            MagicSquareTest test = new MagicSquareTest(new MagicSquare(dimension));
            test.perform();
            
            long endTime = System.currentTimeMillis();
            test.printMatrix();
            System.out.println("Execution time: " + (endTime - startTime)*0.001);
        
        }
        
    }
*/

//--------------------------------------  15 sec - postprocessing...
	public static void main (final java.lang.String[] args_2)
	{
	  int i_4790 = 0;
	  WHILE_4791:
	  while (i_4790 < MagicSquareTest.iprint) {
	    final long startTime_4796 = java.lang.System.currentTimeMillis() /*static*/;
	    final double[][] m2_5123 = new double[5][5];
	    final double[][] m3_5129 = new double[5][5];
	    final double[] m2_0_5118 = m2_5123[0];
	    m2_0_5118[0] = 0.16923076923076924D;
	    m2_0_5118[1] = 0.06153846153846154D;
	    m2_0_5118[2] = 0.26153846153846155D;
	    m2_0_5118[3] = 0.15384615384615385D;
	    m2_0_5118[4] = 0.35384615384615387D;
	    final double[] m2_1_5119 = m2_5123[1];
	    m2_1_5119[0] = 0.36923076923076925D;
	    m2_1_5119[1] = 0.18461538461538463D;
	    m2_1_5119[2] = 0.07692307692307693D;
	    m2_1_5119[3] = 0.27692307692307694D;
	    m2_1_5119[4] = 0.09230769230769231D;
	    final double[] m2_2_5120 = m2_5123[2];
	    m2_2_5120[0] = 0.1076923076923077D;
	    m2_2_5120[1] = 0.38461538461538464D;
	    m2_2_5120[2] = 0.2D;
	    m2_2_5120[3] = 0.015384615384615385D;
	    m2_2_5120[4] = 0.2923076923076923D;
	    final double[] m2_3_5121 = m2_5123[3];
	    m2_3_5121[0] = 0.3076923076923077D;
	    m2_3_5121[1] = 0.12307692307692308D;
	    m2_3_5121[2] = 0.3230769230769231D;
	    m2_3_5121[3] = 0.2153846153846154D;
	    m2_3_5121[4] = 0.03076923076923077D;
	    final double[] m2_4_5122 = m2_5123[4];
	    m2_4_5122[0] = 0.046153846153846156D;
	    m2_4_5122[1] = 0.24615384615384617D;
	    m2_4_5122[2] = 0.13846153846153847D;
	    m2_4_5122[3] = 0.3384615384615385D;
	    m2_4_5122[4] = 0.23076923076923078D;
	    double[][] m2_7775 = m2_5123;
	    double[][] m3_7774 = m3_5129;
	    int iter_7772 = 0;
	    while (iter_7772 < MagicSquareTest.iters) {
	      m3_7774[0][0] = 0.16923076923076924D * m2_7775[0][0] + 0.36923076923076925D * m2_7775[0][1] + 0.1076923076923077D * m2_7775[0][2] + 0.3076923076923077D * m2_7775[0][3] + 0.046153846153846156D * m2_7775[0][4];
	      m3_7774[0][1] = 0.06153846153846154D * m2_7775[0][0] + 0.18461538461538463D * m2_7775[0][1] + 0.38461538461538464D * m2_7775[0][2] + 0.12307692307692308D * m2_7775[0][3] + 0.24615384615384617D * m2_7775[0][4];
	      m3_7774[0][2] = 0.26153846153846155D * m2_7775[0][0] + 0.07692307692307693D * m2_7775[0][1] + 0.2D * m2_7775[0][2] + 0.3230769230769231D * m2_7775[0][3] + 0.13846153846153847D * m2_7775[0][4];
	      m3_7774[0][3] = 0.15384615384615385D * m2_7775[0][0] + 0.27692307692307694D * m2_7775[0][1] + 0.015384615384615385D * m2_7775[0][2] + 0.2153846153846154D * m2_7775[0][3] + 0.3384615384615385D * m2_7775[0][4];
	      m3_7774[0][4] = 0.35384615384615387D * m2_7775[0][0] + 0.09230769230769231D * m2_7775[0][1] + 0.2923076923076923D * m2_7775[0][2] + 0.03076923076923077D * m2_7775[0][3] + 0.23076923076923078D * m2_7775[0][4];
	      m3_7774[1][0] = 0.16923076923076924D * m2_7775[1][0] + 0.36923076923076925D * m2_7775[1][1] + 0.1076923076923077D * m2_7775[1][2] + 0.3076923076923077D * m2_7775[1][3] + 0.046153846153846156D * m2_7775[1][4];
	      m3_7774[1][1] = 0.06153846153846154D * m2_7775[1][0] + 0.18461538461538463D * m2_7775[1][1] + 0.38461538461538464D * m2_7775[1][2] + 0.12307692307692308D * m2_7775[1][3] + 0.24615384615384617D * m2_7775[1][4];
	      m3_7774[1][2] = 0.26153846153846155D * m2_7775[1][0] + 0.07692307692307693D * m2_7775[1][1] + 0.2D * m2_7775[1][2] + 0.3230769230769231D * m2_7775[1][3] + 0.13846153846153847D * m2_7775[1][4];
	      m3_7774[1][3] = 0.15384615384615385D * m2_7775[1][0] + 0.27692307692307694D * m2_7775[1][1] + 0.015384615384615385D * m2_7775[1][2] + 0.2153846153846154D * m2_7775[1][3] + 0.3384615384615385D * m2_7775[1][4];
	      m3_7774[1][4] = 0.35384615384615387D * m2_7775[1][0] + 0.09230769230769231D * m2_7775[1][1] + 0.2923076923076923D * m2_7775[1][2] + 0.03076923076923077D * m2_7775[1][3] + 0.23076923076923078D * m2_7775[1][4];
	      m3_7774[2][0] = 0.16923076923076924D * m2_7775[2][0] + 0.36923076923076925D * m2_7775[2][1] + 0.1076923076923077D * m2_7775[2][2] + 0.3076923076923077D * m2_7775[2][3] + 0.046153846153846156D * m2_7775[2][4];
	      m3_7774[2][1] = 0.06153846153846154D * m2_7775[2][0] + 0.18461538461538463D * m2_7775[2][1] + 0.38461538461538464D * m2_7775[2][2] + 0.12307692307692308D * m2_7775[2][3] + 0.24615384615384617D * m2_7775[2][4];
	      m3_7774[2][2] = 0.26153846153846155D * m2_7775[2][0] + 0.07692307692307693D * m2_7775[2][1] + 0.2D * m2_7775[2][2] + 0.3230769230769231D * m2_7775[2][3] + 0.13846153846153847D * m2_7775[2][4];
	      m3_7774[2][3] = 0.15384615384615385D * m2_7775[2][0] + 0.27692307692307694D * m2_7775[2][1] + 0.015384615384615385D * m2_7775[2][2] + 0.2153846153846154D * m2_7775[2][3] + 0.3384615384615385D * m2_7775[2][4];
	      m3_7774[2][4] = 0.35384615384615387D * m2_7775[2][0] + 0.09230769230769231D * m2_7775[2][1] + 0.2923076923076923D * m2_7775[2][2] + 0.03076923076923077D * m2_7775[2][3] + 0.23076923076923078D * m2_7775[2][4];
	      m3_7774[3][0] = 0.16923076923076924D * m2_7775[3][0] + 0.36923076923076925D * m2_7775[3][1] + 0.1076923076923077D * m2_7775[3][2] + 0.3076923076923077D * m2_7775[3][3] + 0.046153846153846156D * m2_7775[3][4];
	      m3_7774[3][1] = 0.06153846153846154D * m2_7775[3][0] + 0.18461538461538463D * m2_7775[3][1] + 0.38461538461538464D * m2_7775[3][2] + 0.12307692307692308D * m2_7775[3][3] + 0.24615384615384617D * m2_7775[3][4];
	      m3_7774[3][2] = 0.26153846153846155D * m2_7775[3][0] + 0.07692307692307693D * m2_7775[3][1] + 0.2D * m2_7775[3][2] + 0.3230769230769231D * m2_7775[3][3] + 0.13846153846153847D * m2_7775[3][4];
	      m3_7774[3][3] = 0.15384615384615385D * m2_7775[3][0] + 0.27692307692307694D * m2_7775[3][1] + 0.015384615384615385D * m2_7775[3][2] + 0.2153846153846154D * m2_7775[3][3] + 0.3384615384615385D * m2_7775[3][4];
	      m3_7774[3][4] = 0.35384615384615387D * m2_7775[3][0] + 0.09230769230769231D * m2_7775[3][1] + 0.2923076923076923D * m2_7775[3][2] + 0.03076923076923077D * m2_7775[3][3] + 0.23076923076923078D * m2_7775[3][4];
	      m3_7774[4][0] = 0.16923076923076924D * m2_7775[4][0] + 0.36923076923076925D * m2_7775[4][1] + 0.1076923076923077D * m2_7775[4][2] + 0.3076923076923077D * m2_7775[4][3] + 0.046153846153846156D * m2_7775[4][4];
	      m3_7774[4][1] = 0.06153846153846154D * m2_7775[4][0] + 0.18461538461538463D * m2_7775[4][1] + 0.38461538461538464D * m2_7775[4][2] + 0.12307692307692308D * m2_7775[4][3] + 0.24615384615384617D * m2_7775[4][4];
	      m3_7774[4][2] = 0.26153846153846155D * m2_7775[4][0] + 0.07692307692307693D * m2_7775[4][1] + 0.2D * m2_7775[4][2] + 0.3230769230769231D * m2_7775[4][3] + 0.13846153846153847D * m2_7775[4][4];
	      m3_7774[4][3] = 0.15384615384615385D * m2_7775[4][0] + 0.27692307692307694D * m2_7775[4][1] + 0.015384615384615385D * m2_7775[4][2] + 0.2153846153846154D * m2_7775[4][3] + 0.3384615384615385D * m2_7775[4][4];
	      m3_7774[4][4] = 0.35384615384615387D * m2_7775[4][0] + 0.09230769230769231D * m2_7775[4][1] + 0.2923076923076923D * m2_7775[4][2] + 0.03076923076923077D * m2_7775[4][3] + 0.23076923076923078D * m2_7775[4][4];
	      final int iter_9246 = iter_7772 + 1;
	      final double[][] m2_9256 = m2_7775;
	      m2_7775 = m3_7774;
	      m3_7774 = m2_9256;
	      iter_7772 = iter_9246;
	      continue;}
	    /*while*/
	    final long endTime_9258 = java.lang.System.currentTimeMillis() /*static*/;
	    if (m2_7775 == null) {
	      java.lang.System.out.println("Execution time: " + (double)(endTime_9258 - startTime_4796) * 0.001D) /*virtual*/;
	      i_4790++;
	      continue WHILE_4791;}
	    else {
	      java.lang.System.out.print(m2_7775[0][0] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[0][1] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[0][2] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[0][3] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[0][4] + " ") /*virtual*/;
	      java.lang.System.out.println() /*virtual*/;
	      java.lang.System.out.print(m2_7775[1][0] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[1][1] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[1][2] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[1][3] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[1][4] + " ") /*virtual*/;
	      java.lang.System.out.println() /*virtual*/;
	      java.lang.System.out.print(m2_7775[2][0] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[2][1] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[2][2] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[2][3] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[2][4] + " ") /*virtual*/;
	      java.lang.System.out.println() /*virtual*/;
	      java.lang.System.out.print(m2_7775[3][0] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[3][1] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[3][2] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[3][3] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[3][4] + " ") /*virtual*/;
	      java.lang.System.out.println() /*virtual*/;
	      java.lang.System.out.print(m2_7775[4][0] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[4][1] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[4][2] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[4][3] + " ") /*virtual*/;
	      java.lang.System.out.print(m2_7775[4][4] + " ") /*virtual*/;
	      java.lang.System.out.println() /*virtual*/;
	      java.lang.System.out.println("Execution time: " + (double)(endTime_9258 - startTime_4796) * 0.001D) /*virtual*/;
	      i_4790++;
	      continue WHILE_4791;}}
	  /*WHILE_4791*/
	  return;
	}
//--------------------------------------  25 sec - JScp version 0.0.75

}